==> dingtalk-cli-pro-0.0.53.tgz: package/lib/commands/dev.js <==
const shelljs = require('shelljs');
const util = require('../util');
const chalk = require('chalk');
const debug = require('debug')('dingtalk-cli-pro:dev')
const path = require('path');
const lodash = require('lodash');
const config = require('../../bin/config');
const WHITE_LIST = config.WHITE_LIST;
const brandName = config.brandName;
const spawn = require('../util/spawn-command');

const checkValidLocalIndetName = (localIdentName) => {
 
  for (let i = 0; i < localIdentName.length; i++) {
    if (WHITE_LIST.indexOf(localIdentName[i]) === -1) {
      return false
    }
  }

  return true
}

module.exports = function(client) {
  client
  .registryCommand('dev')
  .alias('d')
  .description(chalk.yellow('️️️️Start Local Development'))
  .action(async () => {
    const abcJson = util.getAbcJson(path.resolve(process.cwd(), './abc.json'));
    const plugin = abcJson.plugin || {};
    const noLocalIdentName = (abcJson.config || {}).noLocalIdentName || [];

    if (lodash.isEmpty(plugin) || !lodash.isArray(plugin.cmd) ) {
      this.log.error(`abc json plugin property is null`, plugin);
      process.exit(1)
    }
    const pluginName = plugin.name;
    
    if (util.isPluginName(pluginName)) {      
      const cmd = noLocalIdentName.length ? plugin.cmd.concat(['-n', noLocalIdentName.join('|')]) :  plugin.cmd;
      
      spawn.spawnCommandSync(config.clientName, cmd)

    } else {
      this.log.error(`plugin name ${pluginName} is illegal, example: ${brandName}-plugin-xx, ${WHITE_LIST.map(prefix => prefix + '/' + brandName + '-plugin-xx').join(', ')}`)
    }    
  });
}

==> dingtalk-cli-pro-0.0.63.tgz: package/lib/commands/dev.js <==
const shelljs = require('shelljs');
const util = require('../util');
const chalk = require('chalk');
const debug = require('debug')('dingtalk-cli-pro:dev')
const path = require('path');
const lodash = require('lodash');
const config = require('../../bin/config');
const WHITE_LIST = config.WHITE_LIST;
const brandName = config.brandName;
const spawn = require('../util/spawn-command');

module.exports = function(client) {
  client
  .registryCommand('dev')
  .alias('d')
  .description(chalk.yellow('️️️️Start Local Development'))
  .action(async () => {
    const abcJson = util.getAbcJson(path.resolve(process.cwd(), './abc.json'));
    const plugin = abcJson.plugin || {};
    const abcConfig = abcJson.config || {};
    const noLocalIdentName = abcConfig.noLocalIdentName || [];

    if (lodash.isEmpty(plugin) || !lodash.isArray(plugin.cmd) ) {
      this.log.error(`abc json plugin property is null`, plugin);
      process.exit(1)
    }
    const pluginName = plugin.name;
    
    if (util.isPluginName(pluginName)) {      
      let cmd = plugin.cmd;
      if (noLocalIdentName.length) {
        cmd = cmd.concat(['-n', noLocalIdentName.join('|')])
      }
     
      if (plugin.nodeModulesRegExp) {
        cmd = cmd.concat(['-p', plugin.nodeModulesRegExp])
      }
      
      spawn.spawnCommandSync(config.clientName, cmd)

    } else {
      this.log.error(`plugin name ${pluginName} is illegal, example: ${brandName}-plugin-xx, ${WHITE_LIST.map(prefix => prefix + '/' + brandName + '-plugin-xx').join(', ')}`)
    }    
  });
}
